#
# spec file for package python-agate
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
%define modname agate
Name:           python-agate
Version:        1.12.0
Release:        1.1
Summary:        Data analysis library optimized for humans instead of machines
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/wireservice/agate
Source:         https://github.com/wireservice/agate/archive/refs/tags/%{version}.tar.gz#/agate-%{version}.tar.gz
BuildRequires:  %{python_module Babel >= 2.0}
BuildRequires:  %{python_module isodate >= 0.5.4}
BuildRequires:  %{python_module leather >= 0.3.2}
BuildRequires:  %{python_module parsedatetime >= 2.1}
BuildRequires:  %{python_module python-slugify >= 1.2.1}
BuildRequires:  %{python_module pytimeparse >= 1.1.5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  glibc-locale
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module cssselect >= 0.9.1}
BuildRequires:  %{python_module lxml >= 0.3.2}
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       python-Babel >= 2.0
Requires:       python-isodate >= 0.5.4
Requires:       python-leather >= 0.3.2
Requires:       python-parsedatetime >= 2.1
Requires:       python-python-slugify >= 1.2.1
Requires:       python-pytimeparse >= 1.1.5
Recommends:     python-PyICU >= 2.4.2
BuildArch:      noarch
%python_subpackages

%description
Agate is a Python data analysis library that is optimized for humans
instead of machines. It is an alternative to numpy and pandas that
solves real-world problems with readable code.

Agate was previously known as journalism.

%prep
%setup -q -n agate-%{version}
find agate -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} \;

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest -k 'not test_join'

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license COPYING
%{python_sitelib}/agate
%{python_sitelib}/agate-%{version}*-info

%changelog
* Sat Sep 28 2024 Dirk Müller <dmueller@suse.com>
- update to 1.12.0:
  * feat: :class:`.Number` accepts a no_leading_zeroes keyword
    argument, to indicate whether to disallow numbers with
    leading zeroes (not including a single zero, or a single zero
    before a decimal).
* Wed Jun 12 2024 Dirk Müller <dmueller@suse.com>
- update to 1.11.0:
  * fix: The key argument to :meth:`.Table.to_json` errors if two
    values are equal, even if their CSV representation is
    different: for example, "1/1/2020" and "01/01/2020". However,
    until now, this was not the case for numbers: for example,
    "3.0" was treated as unequal to "3.00".
* Fri May  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.10.2:
  * fix: Version 1.10.0 errors on piped data.
  * fix: :meth:`.Number.csvify` returns a Decimal (or None),
    instead of str. :meth:`.Table.to_csv` with
    quoting=csv.QUOTE_NONNUMERIC now works.
  * feat: :meth:`.Table.from_csv` reads the file line by line. If
    sniff_limit=None, it reads the file into memory once, instead
    of twice. If column_types is a :class:`.TypeTester`, it reads
    the file into memory. (#778)
  * fix: Fix :meth:`.TableSet.print_structure` for nested
    tablesets.
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.1:
  * Add Babel 2.14 support.
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.0:
  * feat: Add a ``text_truncation_chars`` configuration for
    values that exceed ``max_column_width`` in
    :meth:`.Table.print_table` and :meth:`.Table.print_html`.
  * feat: Add a ``number_truncation_chars`` configuration for
    values that exceed ``max_precision`` in
    :meth:`.Table.print_table` and :meth:`.Table.print_html`.
  * feat: Lowercase the ``null_values`` provided to individual
    data types, since all comparisons to ``null_values`` are
    case-insensitive. (#770)
  * feat: :class:`.Mean` works with :class:`.TimeDelta`. (#761)
  * Switch from ``pytz`` to ``ZoneInfo``.
  * Add Python 3.12 support.
  * Drop Python 3.7 support (end-of-life was June 27, 2023).
* Thu Mar  9 2023 pgajdos@suse.com
- python-six is not required
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.1:
  * Allow parsedatetime 2.6.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Drop support for Python 2.7 (no longer works) and 3.6 (no longer
    tested).
* Tue Mar  1 2022 Dirk Müller <dmueller@suse.com>
- buildrequire glibc-locale for tests
* Sat Jan 15 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.6.3
  * feat: Table.from_csv() accepts a row_limit keyword argument.
    (#740)
  * feat: Table.from_json() accepts an encoding keyword argument.
    (#734)
  * feat: Table.print_html() accepts a max_precision keyword
    argument, like Table.print_table(). (#753)
  * feat: TypeTester accepts a null_values keyword argument, like
    individual data types. (#745)
  * feat: Min, Max and Sum (#735) work with TimeDelta.
  * feat: FieldSizeLimitError includes the line number in the error
    message. (#681)
  * feat: csv.Sniffer warns on error while sniffing CSV dialect.
  * fix: Table.normalize() works with basic processing methods.
    (#691)
  * fix: Table.homogenize() works with basic processing methods.
    (#756)
  * fix: Table.homogenize() casts compare_values and default_row.
    (#700)
  * fix: Table.homogenize() accepts tuples. (#710)
  * fix: TableSet.group_by() accepts input with no rows. (#703)
  * fix: TypeTester warns if a column specified by the force
    argument is not in the table, instead of raising an error.
    (#747)
  * fix: Aggregations return None if all values are None, instead
    of raising an error. Note that Sum, MaxLength and MaxPrecision
    continue to return 0 if all values are None. (#706)
  * fix: Ensure files are closed when errors occur. (#734)
  * build: Make PyICU an optional dependency.
* Thu Jul 15 2021 Matej Cepl <mcepl@suse.com>
- Fixed URL of the tarball, and the tarball refreshed.
* Wed Jul 14 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to 1.6.2 - March 10, 2021
  * feat: :meth:`.Date.__init__` and :meth:`.DateTime.__init__`
    accepts a locale keyword argument (e.g. en_US) for parsing
    formatted dates. (#730)
  * feat: :meth:`.Number.cast` casts True to 1 and False to 0.
    (#733)
  * fix: :meth:`.utils.max_precision` ignores infinity when
    calculating precision. (#726)
  * fix: :meth:`.Date.cast` catches OverflowError when type
    testing. (#720)
  * Included examples in Python package. (#716)
- Enable test_sniffer test again
* Thu Sep 24 2020 Hans-Peter Jansen <hpj@urpla.net>
- Disable another failing test: test_sniffer
  https://github.com/wireservice/agate/issues/746
* Thu Jun 25 2020 Matej Cepl <mcepl@suse.com>
- Revert previous commit (sr#813277): unittest2 is necessary
  for platforms with Python 2.7 (SLE-15 etc.).
* Wed Jun 10 2020 Matej Cepl <mcepl@suse.com>
- Remove unnecessary dependency on unittest2
* Thu Apr 23 2020 Steve Kowalik <steven.kowalik@suse.com>
- Only BuildRequire unittest2 under Python 2.
* Thu Apr 16 2020 Matej Cepl <mcepl@suse.com>
- Switch from using nosetest runner to pytest
* Sat Mar  2 2019 Hans-Peter Jansen <hpj@urpla.net>
- export LANG=en_US.UTF-8 for tests
  build fails for python < 3.7 otherwise
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable tests
- Remove devel dependency
- Switch to github tarball to get test fixtures and data
* Wed May  9 2018 toddrme2178@gmail.com
- Update to 1.6.1
  * `Date.cast` and :meth:`DateTime.cast` will no longer parse
    strings that contain dates as dates. (#705)
  * Added Forest Gregg to Authors.
  * `Table.to_json` can now use Decimal as keys. (#696)
  * Link to tutorial now uses version through sphinx to avoid bad
    links on future releases. (#682)
  * lxml limited to >= 3.6 and < 4 for pypy compatibility.
- Use license tag
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
